c--------------------------------------------------------------------
      subroutine ampcla(nan,nw,NDMT,knmin,knmax,itrjmx1,wgt,
     &     th_c_rad,sintq,sval,tmasx,lparmn,lparmx)
c--------------------------------------------------------------------
C    Sub-main program for DWIA calculation,
C    calling the subroutines 'ampsub', 'ovlap', 'sobcal'
C      
c    In subroutine ampsub, calculate the amplitudes 
c         samp(nr,itrj,imj,msf,msi,ip,ils)
c           nr  : mesh point of r
c           itrj: Jtr + 1; transferred J
c           imj : mj-jtr ; m-component of Jtr
c           msf : index of final spin projection
c           msi : index of initial spin projection
c           ip  : index of transferred parity, ip = 1; no, = 2; yes
c           ils : index of transferred s and l          
c    In subroutine ovlap, 
C     calculate the scattering amplitudes in m-representation 
c      ampm(msf,msi,msf',msi',kn,NDM) : 
C       Response functions R_S for the (outer impact) source function S. 
c       msi, msi': z-comp. of the nucleon spin in the incident channel 
c       msf, msf': z-comp. of the nucleon spin in the exit channel 
c       kn: =1: natural prity, =2: unnatural parity
c       NDM: N/Delta-hole specification
c            =1;(N<->N), =2;(N<->D), =3;(D<->D), = NDMT(=1 or 4);full 
C    In subroutine sobcal, 
C     calculate the cross sections and spin obsevables
C
c------------------------------------------------------------------------
C  INPUT THROUGH THE ARGUMENTS
C    nan  : angle number
C    nw   : transferred energy number
c    NDMT : maximum of Nucleon-Delta index NDM
c           NDM; Response function specification 
C           for N/Delta-hole components or sum of them (full)
c           =1;(N<->N), =2;(N<->D), =3;(D<->D), =NDMT(=1 or 4);full            
C    knmin   : minimum of transferred parity specification
C    knmax   : maximum of transferred parity specification
C    wgt     : weight for integration
C    th_c_rad: scattering angle in the c.m. (rad)
c    sintq   : sin(thq')=sin(pi-thq)=sin(pi/2-thp)=cos(thp)
C                       [ thq',thp < pi/2)] defined in basic3,f
C    itrjmx1 : maximum of transferred J
C    sval    : s-value of the scattering system in MeV^2
C    tmasx(i): i=1;target mass, i=2; residual nucleus mass in MeV
C
C  INPUT FROM COMMON fund1            
c    itrjmn: minimum of transferred J
c    nsrmax: number of mesh points in response func. calculation
C    dsr   : radius mesh size in response func. calculation
C  INPUT FROM COMMON BASE 
c    pspn1(2): The spin of the projectile and the ejectile
C    Atg    :  Target mass number
C  INPUT FROM COMMON OPEP 
C    fratio : : f_piND/f_piNN; piND-piNN coupling ratio
C  INPUT FROM COMMON CNTL 
C    KTAMP  : specify the included types of the NN amplitudes
c                for ampl(r,theta,m,msf,msi,ip,ils)
C------------------------------------------------------------------------
C  OUTPUT FROM OVLAP (INPUT TO SOBCAL) IN COMMON AMPM
c    ampm(msf,msi,msf',msi',kn,NDM) : 
C      Response functions R_{S} for the (outer impact) source function S. 
c       msi, msi': z-components of the nucleon spin in the incident channel 
c       msf, msf': z-components of the nucleon spin in the exit channel 
c       kn; =1: natural prity, =2: unnatural parity
c       NDM; N/Delta-hole specification(see above) 
c
c------------------------------------------------------------------------
      include 'dimn.fh'
      include 'cntl.fh'
      include 'base.fh'
      include 'fund1.fh'
      include 'opep.fh'
c
      real*4 wgt(*),tmasx(2)
      complex samp(nsrdm,njdm,njdm2,2,2,2,2)
      complex ampm(2,2,2,2,2,4)
c
      ijmn1=itrjmn+1
      ijmx1=itrjmx1+1
c=====================================================================
c  Make samp
C=====================================================================
      call ampsub(th_c_rad,ijmn1,ijmx1,nsrmax,samp,KTAMP,lparmn,lparmx)
C--------------------------------------------------------------------
c    loop of transferred J
c-------------------------------------------------------------------
      do 30 itrj=ijmn1,ijmx1
C====================================================================
c  overlap of f*r*f ;  calculate ampm 
C--------------------------------------------------------------------
         call ovlap(itrj,nw,samp,wgt,ampm,NDMT,KTAMP,nsrmax,dsr,
     &        pspn1,Atg,fratio,sval,tmasx)
C====================================================================
c  calc spin observables(j component)
c---------------------------------------------------------------------
         call sobcal(nan,itrj,ampm,NDMT,knmin,knmax,sintq)
C=====================================================================
C  Output cross sections,and spin obsevables for respective Jtr
C---------------------------------------------------------------------
         if(KTOUT_XSJ.eq.1) then
            omeg_l=omegld(nw)      
            call wxsecJ(nan,omeg_l,itrj,NDMT,knmin,knmax,pspn1)
         end if
c---------------------------------------------------------------------
 30   continue  !End of Jtr do-loop
C
      return
      end
