c---------------------------------------------------------------------

      subroutine ampsub(th_c_rad,ijmn1,ijmx1,nsrmax,samp,KTAMP,
     &     lparmn,lparmx)

c---------------------------------------------------------------------
c   Calculation of distorted wave vertex amplitudes
c    f^{msf,msi}_{(ls)JM}(r)*ki*kf*r^2 of PRC63('01)044609
c
c-----------------------------------------------------------------------
C  INPUT THROUGH THE ARGUMENTS
C    th_c_rad: scattering angle in cm  (rad) 
C    ijmn1  : minimum of transferred J+1   
C    ijmx1  : maximum of transferred J+1
C    nsrmax : number of mesh points in response func. calculation
C    KTAMP  : specify the included types of the NN amplitudes
c                for ampl(r,theta,m,msf,msi,ip,ils)
C    lparmn : minimum partial wave orbital angular momentum
C    lparmx : maximum partial wave orbital angular momentum
c
C  INPUT FROM COMMON CNTL 
C    KTAMP  : specify the included types of the NN amplitudes
c                for ampl(r,theta,m,msf,msi,ip,ils)
c              = 0 : A+C1+C2+E+F+(B-F) (full calculation)
c              = 1 : A
c              = 2 : C1
c              = 3 : C2
c              = 4 : E
c              = 5 : F
c              = 6 : B-F
c              = 7 : E+F+(B-F)
c              = 8 : A+C1 (s=0 excitation dominant)
c              = 9 : E+F+(B-F)+C2 (s=1 excitation dominant)
C  INPUT FROM COMMON 
c    pz1(2) : projectile/ejectile charge  
C  INPUT FROM COMMON BASE 
c    pspn1(2): The spin of the projectile and the ejectile 
C  INPUT FROM COMMON DIMN 
c    mdm  : dimension for m of the partial waves
c    nldm : dimension for the partial waves
c    nsrdm: dimension for the radial mesh for response func. calc.
c    njdm : dimension for the transferred J
c    njdm2: dimension for M of the transferred J (2*njdm+1)
C  INPUT FROM COMMON COUL 
c    sglcs(lf,2): cos(sigma_l)                                               
c    sglsn(lf,2): sin(sigma_l) 
C  INPUT FROM COMMON CLEBS                    
c    faclog(*): Table of log of factorials
C  INPUT FROM COMMON DW                    
c    dwd:Table of distorted waves 
C
C---------------------------------------------------------------------
C  OUTPUT  THROUGH THE ARGUMENTS
c    samp(nr,itrj,imj,msf,msi,ip,ils): Distorted wave vertex amplitudes
c      nr: radial mesh number
c      itrj: transferred J index 
c      imj
c      msf:z-components of the nucleon spin in the exit channel
c      msi:z-components of the nucleon spin in the incident channel 
c      ip
c      ils
c                        
c----------------------------------------------------------------------
      include 'dimn.fh'
      include 'base.fh'
      include 'coul.fh'
      include 'dw.fh'
      include 'clebs.fh'
c
      complex samp(nsrdm,njdm,njdm2,2,2,2,2)
      complex cdw(nsrdm)
      complex fac1,fac2,fac3,fac4,fac8,fac9
      dimension plmt(mdm,nldm),plm(mdm)
      dimension fyl(mdm,nldm)
      real*8 cpi/3.141592654d0/
c
      limin=lparmn+1
      lfmin=lparmn+1
      limax=lparmx+1
      lfmax=lparmx+1
c      
      isiw=2.0*pspn1(1)+0.01
      isfw=2.0*pspn1(2)+0.01
      mxsi=isiw+1
      mxsf=isfw+1
c
      if((KTAMP.eq.0).or.(KTAMP.eq.3).or.
     &   (KTAMP.eq.6).or.(KTAMP.eq.7).or.(KTAMP.eq.9)) then
        ijmax=ijmx1+2
        ijmin=max(1,ijmn1-2)
      else
        ijmax=ijmx1
        ijmin=ijmn1
      end if
c=====================================================================
c   Set isospin factors
c     <p'|tau_0|p> = 1, <n'|tau_0|n> = -1
c     <p|tau_{+1}|n> = -sqrt(2), <n|tau_{-1}|p> = sqrt(2)
c--------------------------------------------------------------------
      facisp=0.0
      if(pz1(1).eq.1.0) then
        if(pz1(2).eq.1.0) facisp=1.0
        if(pz1(2).eq.0.0) facisp=sqrt(2.0)
      else if(pz1(1).eq.0.0) then
        if(pz1(2).eq.1.0) facisp=-sqrt(2.0)
        if(pz1(2).eq.0.0) facisp=-1.0
      else
        write(6,9050)
 9050   format('isospin factor is zero in ampcla')
        stop
      end if
c=====================================================================
c  Initialization
c--------------------------------------------------------------------
      do nsr=1,nsrmax
        cdw(nsr)=(0.0,0.0)
      end do
c=====================================================================
c   Loop of transferred J (Jtr)
c--------------------------------------------------------------------
      do 10 itrj=ijmin,ijmax
        jtr  =itrj-1
        jtr1w=jtr*2
        mxjp=jtr1w+1
        mshif=-jtr1w-2
        fac0=sqrt(4.0*cpi)*facisp*sqrt(float(jtr1w+1))
c=====================================================================
c    Initialization of samp
c---------------------------------------------------------------------
        do ils=1,2
          do ip=1,2
            do n4=1,mxsi
              do n3=1,mxsf
                do m =1,mxjp
                  do nr=1,nsrmax
                    samp(nr,itrj,m,n3,n4,ip,ils)=(0.0,0.0)
                  end do
                end do
              end do
            end do
          end do
        end do
c=====================================================================
c   Set associated Legendre functions
c---------------------------------------------------------------------
        cs_cm=cos(th_c_rad)
       do lfcr=1,lfmax
         lc1=lfcr-1
         mmax=min0((jtr1w+isiw+isfw)/2+1,lc1+1)
           call alegdm(cs_cm,lc1,mmax,mdm,plm)
         do m=1,mmax
            plmt(m,lfcr)=plm(m)
         end do
       end do
c===================================================================
c    loop of lf (l of final channel dw)
c-------------------------------------------------------------------
      do 820 lf=lfmin,lfmax
        lc1=lf-1
        lfw=lc1*2
        fac1=fac0*sqrt(float(lfw+1))*cmplx(sglcs(lf,2),sglsn(lf,2))
        mmax=min0((jtr1w+isiw+isfw)/2+1,lc1+1)
          do mlgd=1,mmax
            n=lf-mlgd+1
            k=lf+mlgd-1
            fyl(mlgd,lf)=exp((faclog(n)-faclog(k))/2.)
          end do
c=================================================================
c   loop of jf (j of final channel dw)
c     for spin 1/2 ejectile  jf=1 --> jf = lf-1/2
c                            jf=2 --> jf = lf+1/2
c---------------------------------------------------------------
        jfwmin=iabs(lfw-isfw)
        do 810 jf=1,mxsf
          jfw=(jf+lf-2)*2-isfw
C
          if(jfw.ge.jfwmin) then
C======================================================================
c   Loop for parity
c      ip = 1: no parity transfer, ip = 2: parity transfer
c--------------------------------------------------------------------  
      do 800 ip=1,2
c=====================================================================
c   Loop of ltr (transferred l) and str (transferred s)
c     ip = 1 & ils = 1 --> str = 0, ltr = jtr
c              ils = 2 --> str = 1, ltr = jtr
c     ip = 2 & ils = 1 --> str = 1, ltr = jtr - 1
c              ils = 2 --> str = 1, ltr = jtr + 1
c---------------------------------------------------------------------
      do 790 ils=1,2
      itrs=(2-ip)*(ils-1)+ip-1
      is1w=itrs*2
      ltr1=jtr+(ip-1)*(2*ils-3)
      ltr1w=2*ltr1
c=====================================================================
c    Spin reduce matrix element  <N'||1||N> or <N'||sigma||N>
c----------------------------------------------------------------------
      spnrme=0.0
      if((isiw.eq.1).and.(isfw.eq.1).and.(is1w.eq.0)) spnrme=sqrt(2.0)
      if((isiw.eq.1).and.(isfw.eq.1).and.(is1w.eq.2)) spnrme=sqrt(6.0)
      if(spnrme.lt.0.001) then
        write(6,8000)
        stop
      end if
 8000 format('spin reduced matrix element is zero')
C-------------------------------------------------------------------
      if((jtr.eq.0).and.(ip.eq.1).and.(itrs.eq.1)) go to 790
      if((jtr.eq.0).and.(ip.eq.2).and.(ltr1.ne.1)) go to 790
C-------------------------------------------------------------------
      fac2=fac1*sqrt(float(ltr1w+1))*spnrme
c==================================================================
c   loop of li (l of initial channel dw)
C-----------------------------------------------------------------
      limn=iabs(lf-1-ltr1)+1
      limax1=lf+ltr1
      limx=min0(limax1,limax)
c
      if(limx.ge.limn) then

      do  710  li=limn,limx,2
C
      if(li.ge.limin) then
      liw=(li-1)*2
      fac3=fac2*float(liw+1)*cleb(liw,0,ltr1w,0,lfw,0)
     1    *(-1.0)**((liw-lfw+ltr1w)/4)*cmplx(sglcs(li,1),sglsn(li,1))
c================================================================
c   loop of ji (j of initial channel dw)
c     for spin 1/2 ejectile  ji=1 --> ji = li-1/2
c                            ji=2 --> ji = li+1/2
c---------------------------------------------------------------
      jimin=max0(iabs(jfw-jtr1w),iabs(liw-isiw))
      jimax=min0(jfw+jtr1w,liw+isiw)
c
      do  730  ji=1,mxsi
      jiw=(ji+li-2)*2-isiw
C  {
      if(jiw.ge.jimin) then
      if(jiw.le.jimax) then
        fac4=fac3*sqrt(float(jiw+1))
     &           *u9(liw,isiw,ltr1w,is1w,jiw,jtr1w,lfw,isfw,jfw)
        do nr=1,nsrmax
          cdw(nr)=dwd(nr,jf,lf,2)*dwd(nr,ji,li,1)
        end do
c==============================================================
c   loop of msi (spin z component of incident particle)
C-------------------------------------------------------------
      do 600 msi1=1,mxsi
      msiw=2*msi1-isiw-2
      fac8=fac4*cleb(liw,    0,isiw ,msiw ,jiw,msiw )
c==============================================================
c   loop of msf (spin z component of exit particle)
c--------------------------------------------------------------
      do 600 msf1=1,mxsf
      msfw=2*msf1-isfw-2
c=============================================================
c   loop of mtr
C-------------------------------------------------------------
      do 590 mjr=1,mxjp
      mlfw=2*mjr+mshif-msfw+msiw
      if(mlfw.gt.0) then
        mlfwa=mlfw
        phas=(-1.)**(mlfwa/2)
      else
        mlfwa=-mlfw
        phas=1.
      end if
      mlgd=mlfwa/2+1
      if(mlgd.le.mmax) then
        mjfw=mlfw+msfw
        mjrw=-msiw+mlfw+msfw
        cleble=cleb(lfw,mlfw,isfw ,msfw ,jfw,mjfw)
     1       *cleb(jiw,msiw,jtr1w,mjrw,jfw,mjfw )
        fac9=fac8*phas*cleble*fyl(mlgd,lf)*plmt(mlgd,lf)
c===========================================================
c  loop of radius
c-----------------------------------------------------------
        do nr=1,nsrmax
          samp(nr,itrj,mjr,msf1,msi1,ip,ils)
     1      =samp(nr,itrj,mjr,msf1,msi1,ip,ils)+fac9*cdw(nr)
        end do
      end if
  590 continue
  600 continue
      end if
      end if
  730 continue
      end if
  710 continue
      end if
  790 continue
  800 continue
      end if
  810 continue
  820 continue
   10 continue
C
      return
      end
