c----------------------------------------------------------------------
      subroutine basic3(nan,omegl,prmass,ejmass,tgmass,EFL,energy,
     &     qcm,q_int,fmoel,fcm2l,ampcm2,sintq,th_c_rad,    
     &     sval,tmasx,lparmn,lparmx)
c  Prepare 
C     the kinematic data
C     Coulomb phase shifts and wave functions
C     Optical potentials
C     Distorted waves
C     Optimal factorization parameters
C     Square of the NN t-matrix at q_cm
c----------------------------------------------------------------------
c INPUT THROUGH THE ARGUMENTS
C   nan   :angle number
C   omegl :Transferred energy in MeV
C   prmass:projectile mass in MeV
C   ejmass:ejectile mass in MeV
C   tgmass:target mass in MeV
C   EFL   :Energy for the Franey-Love t-matrix.in MeV 
C          If =0, then incident energy is used for the t-matrix  
C   lparmn : minimum partial wave orbital angular momentum
C   lparmx : maximum partial wave orbital angular momentum
C
C  INPUT FROM COMMON DIMN 
c    mdm  : dimension for m of the partial waves
c    nldm : dimension for the partial waves
c    nsrdm: dimension for the radial mesh for response func. calc.
c    njdm : dimension for the transferred J
c    njdm2: dimension for M of the transferred J (2*njdm+1)
C  INPUT FROM COMMON fund1.fh 
C    nrmax:maximum number of radial mesh points
C    dr   :increment of the radial mesh
c    itrz : transferred charge
C  INPUT FROM COMMON base.fh
C    elabi   :Incident energy in MeV
C    zz1(2)  :products of charges in incident(i=1) and exit(i=2) channel
C  INPUT FROM COMMON theta.fh
C    thetld(nan):Table of the scattering angle in deg
C  INPUT FROM COMMON ampcoef.fh
C    nspl     (=36) :number of angles(-1) for which NN amplitude data are given
C  INPUT FROM COMMON cntl.fh
C    KTOUT_OPT: Optical Potential Output; =0 no, =1: yes
C    KTOUT_DW : Distorted Wave Output; =0 No, =1 yes
c    KTTNN    : NN t-matrix option 
C               = 0 Optimal factorization, = 1 Franey-Love
C
C----------------------------------------------------------------------
C OUTPUT THROUGH THE ARGUMENTS
C   qcm      :Transferred momentum in the cm frame
C   q_int    :Transferred momentum in the intrinsic frame
C   fmoel    :Moeller factor 
C   fcm2l    :Jacobian from cm to lab frame
C   ampcm2(5):Table of the square of the NN-t-matrix amplitudes 
C   sintq    :sin(thq')=sin(pi-thq)=sin(pi/2-thp)=cos(thp)
C             [thq',thp < pi/2)]
C   th_c_rad :scattering angle in the c.m. (rad)
C   sval     : s-value of the scattering system in MeV^2
C   energy   :Energy used for the t-matrix
C   tmasx(i) :i=1;target mass, i=2; residual nucleus mass in MeV
C
C  OUTPUT THROUGH COMMON base.fh
C   ecmd1(1):projectile energy in cm(MeV) 
C   ecmd1(2):ejectile energy in cm(MeV)  
C   fmud1(1):reduced energy of the incident channel (MeV)
C   fmud1(2):reduced energy of the exit channel (MeV)
C   fk1(1)  :relative momentum in the incident channel (fm^{-1})
C   fk1(2)  :relative momentum in the exit channel     (fm^{-1})
C
C  OUTPUT THROUGH COMMON coul.fh
C   sglcs(l,i):cos(sigma_l) coulomb phase shift; 
C              l:partial wave l, i=1: incident, =2: exit channel
C   sglsn(l,i):sin(sigma_l) coulomb phase shift
C              l:partial wave l, i=1: incident, =2: exit channel
C   fd2(l,i)  :regular coulomb wave functions
C   gd2(l,i)  :singular coulomb wave functions
C   fpd2(l,i) :derivative of regular coulomb wave functions
C   gpd2(l,i) :derivative of singular coulomb wave functions
C
C  OUTPUT TROUGH COMMON ampcoef.fh 
C    qmsh(0:nspl):table of transferred momenta 
c                 for which NN amplitude data are given
C    ampa(0:nspl,5):table of the NN scattering amplitudes for spline
C    ampb(0:nspl,5):table of the NN scattering amplitudes for spline
C    ampc(0:nspl,5):table of the NN scattering amplitudes for spline
C    ampd(0:nspl,5):table of the NN scattering amplitudes for spline
C
C--------------------------------------------------------------------
      include 'dimn.fh'
      include 'fund1.fh'
      include 'base.fh'
      include 'theta.fh'
      include 'coul.fh'
      include 'ampcoef.fh'
      include 'cntl.fh'
c
      complex tampfl(10)
      complex spcp
      dimension sigmad(nldm),f(nldm),fp(nldm),g(nldm),gp(nldm)
      dimension pmasx(2),tmasx(2),ecmd1(2),ampcm2(5)
c
C   CONSTANTS
      real*8 hc/197.326968d0/
      real*8 cpi/3.141592654d0/
      real*8 AMU/931.494043d0/
      REAL*8 MN_AV/938.91937d0/
      parameter(alpha=1.0d0/137.036d0)
c===================================================================
c  kinematic variables(originally BASIC2)
c-------------------------------------------------------------------
c     units of variables
c       fkli, fklf   --> 1/fm
c-------------------------------------------------------------------
      pmasx(1) = prmass
      pmasx(2) = ejmass
      tmasx(1) = tgmass
c
c  Laboratory frame
      eli=pmasx(1)+elabi
      plabi=sqrt(elabi*(elabi+2.0*pmasx(1)))
      elf=eli-omegl
      plabf=sqrt((elf-pmasx(2))*(elf+pmasx(2)))
      elft=tmasx(1)+omegl
      sval=(tmasx(1)+pmasx(1))**2+2.*tmasx(1)*elabi
      estar=sqrt(sval)
c
        thl=0.017453293d0*thetld(nan)
        qlab=sqrt(plabi*plabi+plabf*plabf-2*plabi*plabf*cos(thl))
        tmasx(2)=sqrt((elft+qlab)*(elft-qlab))
        tval=(omegl+qlab)*(omegl-qlab)
c
C  CM frame
      do  500  i=1,2
      ichnl1=i
      ecm1 =(sval+pmasx(i)**2-tmasx(i)**2)/(2*estar)
      ecm2 =estar-ecm1
      fmu  =ecm1*ecm2/estar
      prel=sqrt((ecm1+pmasx(i))*(ecm1-pmasx(i)))
      fkay1=prel/hc
      tcm  =prel**2/(2.0*fmu)
      drho1=fkay1*dr
c
      ecmd1(i)=ecm1
      fmud1(i)=fmu
      fk1(i)=fkay1
c==================================================================
c  coulomb parameters and wave functions
      eta0 =alpha*zz1(i)*fmu/prel
      rhomax=drho1*nrmax
      lmax=lparmx+1
      zzz=zz1(i)
      if(zzz.le.0) then
        do 15 l=1,lmax
          sglcs(l,i)=1.0
          sglsn(l,i)=0.0
   15   continue
      else
c
        call sigma(lmax,eta0,sigma0,sigmad)
        do 35 l=1,lmax
          temp=sigmad(l)
          sglcs(l,i)=cos (temp)
          sglsn(l,i)=sin (temp)
   35   continue
      end if
c
      call coulfn(lmax,eta0,zzz,drho1,rhomax,sigma0,f,fp,g,gp)
c
      do 55 l=1,lmax
        fd2(l,i)=f(l)
        gd2(l,i)=g(l)
        fpd2(l,i)=fp(l)
        gpd2(l,i)=gp(l)
   55 continue
c===================================================================
C    Calculate Optical Potentials
      call  pgen2(ichnl1,nrmax,dr,fkay1,sval,pmasx,tmasx,
     &  eta0,tcm,KTOUT_OPT)
c==================================================================
C    Calculate Distoorted Waves
      call diswav(ichnl1,nrmax,drho1,KTOUT_DW,lparmn,lparmx)
C-----------------------------------------------------------------
  500 continue
C==================================================================
C  Scattering angle, Energy transfer, Momentum transfer
C------------------------------------------------------------------
      th_c_rad=asin(plabf*sin(thl)/(fk1(2)*hc))
      omegc=(ecmd1(1)-ecmd1(2))
      qcm=sqrt(omegc*omegc-tval)/hc
      q_int=qcm*tmas(1)/(tmas(1)+pmas(1))
      sintq=plabf*sin(thl)/hc/qcm
c=================================================================
c     Moeller Factor and optimal factorization parameters
c-----------------------------------------------------------------
      prkcm=fk1(1)*hc
      ejkcm=fk1(2)*hc
      fcm2l=plabf/ejkcm
      call opfact(prkcm,ejkcm,th_c_rad,Atg,fmoel,seff)
c=================================================================
C     Calculate NN t-matrix amplitudes at q_cm
c-----------------------------------------------------------------
        q=qcm
c  optimum frame t-matrix
      IF(KTTNN.EQ.0) then
         if(itrz.eq.0) then 
            kttch=4
         else
            kttch=3
         end if
         energy=seff/(2.0*MN_AV)-2.0*MN_AV
         call nnamp(energy,kttch,qmsh,ampqa,ampqb,ampqc,ampqd)
         do i=1,5
            ampcm2(i)=hc*hc*cabs(spcp((nspl+1),qcm,qmsh,
     &           ampqa(0,i),ampqb(0,i),ampqc(0,i),ampqd(0,i)))**2
         end do
c  FL-t-matrix
      ELSE If(KTTNN.EQ.1) then
         energy=elabi
         IF(EFL.GT.0.001) ENERGY=EFL
         call nnamp_fl(qcm,energy,int(Atg),tampfl)
         do i=1,5
            ampcm2(i)=abs(tampfl(2*i))**2
         end do
      end if
c
      return
      end
