      subroutine glopt3(nrmax,ifit,AA,Zt,Zp,Tplab,dx,
     &                  usr,usi,uer,uei,bdrc0)
c
c  Generate the global relativistic optical potential by Hama et al.
c  modified by M. Ichimura  (2009/9/5),2016.4.25
C=======================================================================
C  INPUT
C    nrmax: Maxium mesh points number for r
C           Potentials are calculated up to the point of nrmax+3  
C    ifitc: Parameter set specification
C          =  1: CA40-PB208 (P,P) 65-1040 MEV  FIT.1
c          =  2: CA40-PB208 (P,P) 65-1040 MEV  FIT.2 
c          =  3: C12 (P,P)   29-1040 MEV (EDAI C12)
c          =  4: O16 (P,P)   23-1040 MEV (EDAI O16)
c          =  5: CA40 (P,P)  21-1040 MEV (EDAI CA40)
c          =  6: ZR90 (P,P)  22-800  MEV (EDAI ZR90)
c          =  7: PB208 (P,P) 21-1040 MEV (EDAI PB208)
c          =  8: C12-PB208 (P,P) 21-1040 MEV (EDAD FIT.1)
c          =  9: C12-PB208 (P,P) 21-1040 MEV (EDAD FIT.2)
c          = 10: C12-PB208 (P,P) 21-1040 MEV (EDAD FIT.3)
c          = 11: 4HE (P,P)   156-1728 MEV (PRC73,024608(2006))
C      AA : Target mass number
C      Zt : Target charge
C      Zp : Projectile charge 
C    Tplab: Projectile Kinetic energy in laab. frame
C      dx : Mesh size of the radius r
C  OUTPUT
C    usr(nx)  : Scalar potential real      part (nx=1-(nrmax+4))
C    usi(nx)  : Scalar potential imaginary part (nx=1-(nrmax+4))    
C    usr(nx)  : Vector potential real      part (nx=1-(nrmax+4))
C    usi(nx)  : Vector potential imaginary part (nx=1-(nrmax+4))
C    bdrc0(nx): (E+M+Us-U0)/(E-M) (nx=1-(nrmax+4))
C   Note: x(nx=1)=0.0. x(nx=2)=dx,  
C-----------------------------------------------------------------------
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      complex bdrc0(*)
      dimension usr(*),usi(*),uer(*),uei(*)
      dimension x(1000)
      DIMENSION VVA(1000),WVA(1000),VSA(1000),WSA(1000)
      DIMENSION AC(5000),DC(5000),DDC(5000)
      COMMON/RECOIL/RECV,RECS
c
      real*8 hc/197.326968d0/
      parameter (amu=931.5016D0)
c
      HC2=HC**2
      nstep=nrmax+4
      do i=1,nstep
         x(i)=dx*float(i-1)
      end do
      WT=AA*AMU
      EE=TPLAB
CC--------------------------------------------------------------
CC TRANSFORM TO 2 BODY CM FRAME AND CALCULATE RECOIL FACTORS
CC
        WP=1.0072545D0*AMU
        AM=WP
        CWT=AA**0.3333333333333333D0
        EL=EE+WP
        WP2=WP**2
        WT2=WT**2
        PCM=DSQRT(WT2*(EL**2-WP2)/(WP2+WT2+2.0D0*WT*EL))
        EPCM=DSQRT(WP2+PCM**2)
        AE=EPCM
        ETCM=DSQRT(WT2+PCM**2)
        SR=EPCM+ETCM
CC
        RECV=(ETCM /SR)
        RECS=(WT/SR)
        redu=epcm*etcm/sr
        facou=recv*ae/redu
        icou=0
        if(zp.eq.0.0) icou=3
C----------------------------------------------------------------- 
CCCCC   COULOMB
      COUF1=1.0
      COUF2=1.0
      IF(ICOU.EQ.1) THEN
         COUF1=0.0
         COUF2=0.0
      END IF
      IF(ICOU.EQ.2) THEN
         COUF1=0.0
         COUF2=1.0
      END IF
      DO 40 J=1,NSTEP
         AC(J)=0.
         DC(J)=0.
         DDC(J)=0.
  40  CONTINUE
      IF(ICOU.EQ.3) GO TO 42
      RV1=1.05
      AV1=0.67
      RCOU=RV1*CWT
      ACOU=AV1*2.0D0*0.56418958D0
      NC=20.0/DX+10
      IF (NC.GT.5000) STOP ' STOP DUE TO NC.GT.5000 '
      CALL COULP3
      CALL OSUCOU(AC,DC,DDC,DX,NSTEP,NC,ZT,WT,RCOU,ACOU)
  42  CONTINUE

CCC---RECOIL FACTOR RECV ON COULOMB IS TAKEN CARE IN OSUCOU
CCC---ERFCOU IS NOT AVAILABLE IN THIS
C----------------------------------------------------------------- 
      CALL GLOBAL(IFIT,TPLAB,AA,X,VVA,WVA,VSA,WSA,NSTEP)
C ---------------------------------------------------------------
C     EXPRESSION OF US,UO,UT
C ---------------------------------------------------------------
      DO 50 I=1,NSTEP
      X(I)=DX*FLOAT(I-1)
      IF(I.EQ.1)X(I)=0.1D-9
      U1=VSA(I)
      W1=WSA(I)
      U2=VVA(I)
      W2=WVA(I)
      CALL DERI6(I,NSTEP,DX,VSA,UD11,UDD1)
      CALL DERI6(I,NSTEP,DX,WSA,WD11,WDD1)
      CALL DERI6(I,NSTEP,DX,VVA,UD22,UDD2)
      CALL DERI6(I,NSTEP,DX,WVA,WD22,WDD2)
 998  FORMAT(' ',F8.3,4E14.5)
C---------------------------------------------------------------
      AAB=AE+AM+U1-U2-AC(I)
      ADR=UD11-UD22-DC(I)
      ADI=WD11-WD22
      ADDR=UDD1-UDD2-DDC(I)
      ADDI=WDD1-WDD2
      AAI=W1-W2
C-------------------------------------------------------------
C     CALCULATION OF SPIN-ORBIT TERMS
      USR(I)=-0.5D0*HC2/REDU/X(I)*(ADR*AAB+ADI*AAI)/(AAB**2+AAI**2)
      USI(I)=-0.5D0*HC2/REDU/X(I)*(ADI*AAB-ADR*AAI)/(AAB**2+AAI**2)
C Our Convention uses (s.l) for spin orbit operator
C      usr(i)=-hc2/redu/x(i)*(adr*aab+adi*aai)/(aab**2+aai**2)
C      usi(i)=-hc2/redu/x(i)*(adi*aab-adr*aai)/(aab**2+aai**2)
C-------------------------------------------------------------
C     CALCULATION OF DARWIN TERMS
      UDR1=-1.0D0/X(I)*(ADR*AAB+ADI*AAI)/(AAB**2+AAI**2)
      UDR2=-0.5D0*(ADDR*AAB+ADDI*AAI)/(AAB**2+AAI**2)
      UDR3=0.75D0*((ADR**2-ADI**2)*(AAB**2-AAI**2)+4.0D0*ADR*ADI*
     1AAB*AAI)/((AAB**2-AAI**2)**2+4.0D0*AAB**2*AAI**2)
      UDRW=0.5D0*HC2/REDU*(UDR1+UDR2+UDR3)
      UDI1=-1.0D0/X(I)*(ADI*AAB-ADR*AAI)/(AAB**2+AAI**2)
      UDI2=-0.5D0*(ADDI*AAB-ADDR*AAI)/(AAB**2+AAI**2)
      UDI3=1.5D0*(ADR*ADI*(AAB**2-AAI**2)-(ADR**2-ADI**2)*AAB*AAI)
     1/((AAB**2-AAI**2)**2+4.0D0*AAB**2*AAI**2)
      UDIW=0.5D0*HC2/REDU*(UDI1+UDI2+UDI3)
C-------------------------------------------------------------
C     CALCULATION OF CENTRAL POTENTIAL TERMS (NO DARWIN)
      UCR1=2.0D0*AE*U2+2.0D0*AM*U1-U2**2+W2**2+U1**2
     1-W1**2-2.0D0*AC(I)*U2
      UCRW=0.5D0/REDU*UCR1
      UCI1=2.0D0*(AE*W2+AM*W1-U2*W2+U1*W1-AC(I)*W2)
      UCIW=0.5D0/REDU*UCI1
C   ------------------------------------------------------
C     CALCULATION OF CENTRAL POTENTIAL (WITH DARWIN)
      UER(I)=UCRW+UDRW-COUF2*0.5D0*AC(I)**2/REDU 
     &     + COUF1*(AE/REDU)*AC(I)
      UEI(I)=UCIW+UDIW
      bdrc0(I)= cmplx(AAB,AAI)/(AE+AM)
   50 CONTINUE
      RETURN
      END
