c ---------------------------------------------------------------------
      subroutine nnamp(tlab,kttch,q,ampa,ampb,ampc,ampd)
c ---------------------------------------------------------------------
c  Prepare the NN t-matrix spline parameters with respect to q 
c  at the given kinetic energy tlab(MeV) obtained by energy spline
c  for the specified reaction by kttch
C  Originally coded by Ulich Goetz, Latest update by M.I. 2013.8.27
c----------------------------------------------------------------------
C  INPUT from argument 
c    tlab : Incident kinetic energy (MeV) 
c       NN t-matrix data are available at the kinetic energies
c      tlab [mev]: 25  50  100  142  210  325  425  515  650  788
c    kttch: Reaction type specification
c       kttch:
c         1    pp --> pp
c         2    np --> np
c         3    np --> pn (c.e.)
c         4   (pp --> pp + np --> np )/2 ! isospin indep. for absorption
c  
c  OUTPUT to argument
c    q(0:36): table of momentum transfers corresponding to scattering angles
c    amp(0:36,5) : NN t-matrix data         
c    ampa(0:36,5): NN t-matrix amplitude spline data for the 0th order
c    ampb(0:36,5): NN t-matrix amplitude spline data for the 1st order
c    ampc(0:36,5): NN t-matrix amplitude spline data for the 2nd order
c    ampd(0:36,5): NN t-matrix amplitude spline data for the 3rd order
c        [0:36]  : Correspond to scattering angles theta_{cm}=0(5)180 deg
c-----------------------------------------------------------------------
      implicit none
      integer kttch,sch,iq
      real q(0:36), tlab
      complex amp(0:36,5),
     1  ampa(0:36,5),ampb(0:36,5),ampc(0:36,5),ampd(0:36,5)
c
c   Calculate amplitudes for 37 angles at the kinetic energy tlab
      call nnamp0(tlab,kttch,q,amp)
c
c   Prepare spline parameters 
      do 150 sch=1,5
        do 130 iq=0,36
          ampa(iq,sch) = amp(iq,sch)
  130   continue
        call sp0cp(37,q,ampa(0,sch),
     *                  ampb(0,sch),ampc(0,sch),ampd(0,sch))
  150 continue
c
      return
      end
