c--------------------------------------------------------------------
      subroutine opfact(fk1,fk3,theta,A,fmoel,seff)
c--------------------------------------------------------------------
c     Calculate Mandelstam variable s of scattering NN system and 
C     the Moeller factor for the transformation 
c     from the NN c.m. frame to the optimum frame
c     Proton neutron mass difference is neglected     
c     By M.I. 2013.8.25
c--------------------------------------------------------------------
c  INPUT from arguments 
c     fk1  : momentum of projectile nucleon in NA-cm frame (MeV)
c     fk3  : momentum of ejectile   nucleon in NA-cm frame (MeV)
c    theta : scattering angle in  NA-cm frame (rad)
c      A   : target mass number
c  OUTPUT to arguments
c    fmoel: Moeller factor from the NN-cm frame to the optimal frame
c    seff: Mandelstam s variable of the NN system
c---------------------------------------------------------------------
C   CONSTANTS
      REAL*8 MN_AV/938.91937d0/
C---------------------------------------------------------------------
C Calculate kinetic variables
      fms =  MN_AV*MN_AV
      fk1s = fk1*fk1
      fk3s = fk3*fk3
      E1   = sqrt(fms+fk1s)
      E3   = sqrt(fms+fk3s)
      omegc= E1-E3
      qcs  = fk1s+fk3s-2.0*fk1*fk3*cos(theta)
      qc   = sqrt(qcs)
      teff = omegc*omegc-qcs
      Ea   = 0.5*(E1+E3)
      fkas = 0.25*(fk1s+fk3s+2.0*fk1*fk3*cos(theta))
      fkaq = -Ea*omegc
c
c Calculation of eta
      eta = -fkaq/(A*qcs)
     1    + (omegc/qc)
     2    *sqrt(0.25-(1.0/teff)*(fms+fkas/A**2-fkaq*fkaq/(A*A*qcs)) )
c
c Calculation of k2,E2 and k4,E4 
      a1   = (A+1.0)/(2.0*A)
      a2   = 1.0-a1
      fk2_z=(eta-a1)*fk1-(eta-a2)*fk3*cos(theta)
      fk2_x=-(eta-a2)*fk3*sin(theta)
      fk4_z= (eta+a2)*fk1-(eta+a1)*fk3*cos(theta)
      fk4_x=-(eta+a1)*fk3*sin(theta)
      E2   = sqrt(fk2_z*fk2_z + fk2_x*fk2_x + fms)
      E4   = sqrt(fk4_z*fk4_z + fk4_x*fk4_x + fms)
c
c Calculation of Mandelstam variable s  
      fk12_z= fk1 + fk2_z
      fk12_x= fk2_x
      E12   = E1+E2
      seff  = E12*E12 - (fk12_z*fk12_z + fk12_x*fk12_x)
c
c Calculation of Moeller factor
      fmoel =0.25*seff/sqrt(E1*E2*E3*E4)
C
      return
      end
