c----------------------------------------------------------------------
      subroutine vdrll_fl(ltrmx,EFL)
c----------------------------------------------------------------------
c      calculation of driving force from Franey-Love NN t-matrix 
c      in the coordinate representation
c      Latest update M.I. 2013.8.26
c---------------------------------------------------------------------
c  INPUT
c    ltrmx : maximum transferred l+1                from arguments
c    EFL   : Incident kimnetic energy in NN lab frame (MeV) from argument
c    nkmax : Maximum number of momentum mesh points  from fund1.fh 
c    nsrmax: number of mesh points for r             from fund1.fh
c    dsr   : mesh size of r                          from fund1.fh
c    elabi : Incident kinetic energy in NA lab frame from base.fh
c    Atg   : Target mass number                      from base.fh
c    fkdmsh(nkdm): Table of momenta for Fourier transform from lgbs.fh
c    fkdwgt(nkdm): Table of weights for Fourier transform from lgbs.fh:
c    bsl(nkdm,nsrdm,nbsldm): Table of spherical Bessel function from lgbs.fh
c  OUTPUT to drive.fh
c    vll(nsrdm,nsrdm,0:nbsldm,2,5): Table of the driving force to drive.fh
c       v(r1,r2,l1,nl2,i);nl2=1 -> l2=l1, nl2=2 ->l2=l1+2 
c       i=1:A =2:B, =3:C, =4:E, =5:F
c---------------------------------------------------------------------
      include 'dimn.fh'
      include 'fund1.fh'
      include 'drive.fh'
      include 'lgbs.fh'
      include 'base.fh'
      complex amp(360,5),sum(5)
      complex tampfl(10)
      real*8 cpi/3.141592654d0/
c
c  table of t-matrices in q-representation
      fac=1.0/cpi
      energy=elabi
      IF(EFL.GT.0.001) ENERGY=EFL
      do 25 k=1,nkmax
        q=fkdmsh(k)
        call nnamp_fl(q,energy,int(Atg),tampfl)
        do 10 i=1,5
           amp(k,i)=2.0*tampfl(2*i)*fac
   10   continue
   25 continue
c
c  bessel transform
      do 300 lk1=1,ltrmx
        do 200 nlk2=1,2
          lk2=lk1+2*(nlk2-1)
          r1=0.0
          do 150 n1=1,nsrmax
            r1=r1+dsr
            n2min=1
            if(lk1.eq.lk2) n2min=n1
            r2=dsr*float(n2min-1)
c
            do 100 n2=n2min,nsrmax
              r2=r2+dsr
c
              do 70 nnn=1,5
   70         sum(nnn)=(0.0,0.0)
c
              do 90 k=1,nkmax
                sk=fkdmsh(k)
                wk=sk*sk*fkdwgt(k)*bsl(k,n1,lk1)*bsl(k,n2,lk2)
                do 80 nnn=1,5
   80             sum(nnn)=sum(nnn)+wk*amp(k,nnn)
   90         continue
c
              do 95 nnn=1,5
                vll(n1,n2,lk1,nlk2,nnn)=sum(nnn)
                if(lk1.eq.lk2) vll(n2,n1,lk1,nlk2,nnn)=sum(nnn)
   95         continue
  100       continue
  150     continue
  200   continue
  300 continue
c
      do  nnn=1,5
       do  nlk2 = 1,2
        do  n2 = 1, nsrmax
         do  n1 = 1,nsrmax
              vll(n1,n2,0,nlk2,nnn)= 0.0
         end do
        end do
       end do
      end do
c
      return
      end
